@@ -71,7 +71,7 @@ from progressbar.widgets import *
 __author__ = 'Rick van Hattem'
 __author_email__ = 'Rick.van.Hattem@Fawo.nl'
 __date__ = str(date.today())
-__version__ = '2.6.7'
+__version__ = '2.6.8'
 
 
 class UnknownLength:
@@ -169,14 +169,16 @@ class ProgressBar(object):
         self.start_time = None
         self.update_interval = 1
 
-    def __call__(self, iterable):
+    def __call__(self, iterable, maxval=None):
         'Use a ProgressBar to iterate through an iterable'
-
-        try:
-            self.maxval = len(iterable)
-        except:
-            if self.maxval is None:
-                self.maxval = UnknownLength
+        if maxval is None:
+            try:
+                self.maxval = len(iterable)
+            except:
+                if self.maxval is None:
+                    self.maxval = UnknownLength
+        else:
+            self.maxval = maxval
 
         self.__iterable = iter(iterable)
         return self
